/*
 * Copyright 2017-2024 original authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package example.micronaut

import io.micronaut.core.async.annotation.SingleResult
import io.micronaut.http.annotation.Get
import io.micronaut.http.annotation.Header
import io.micronaut.http.client.annotation.Client
import org.reactivestreams.Publisher
import static io.micronaut.http.HttpHeaders.ACCEPT
import static io.micronaut.http.HttpHeaders.USER_AGENT

@Client(id = "github") // <1>
@Header(name = USER_AGENT, value = "Micronaut HTTP Client") // <2>
@Header(name = ACCEPT, value = "application/vnd.github.v3+json, application/json") // <3>
public interface GithubApiClient {

    @Get('/repos/${github.organization}/${github.repo}/releases') // <4>
    @SingleResult // <5>
    Publisher<List<GithubRelease>> fetchReleases() // <6>
}
